@@ -107,7 +107,7 @@ function removeDuplicate(patterns) {    // Remove patterns with duplicate symbol
                 last = patterns[i][j];
             }
         }
-        ok = ok && (patterns[i][patterns[i].length - 1] !== first);   // when last equal first, it's a duplicated symbol
+        ok &= (patterns[i][patterns[i].length - 1] !== first);   // when last equal first, it's a duplicated symbol
         if (ok) noDup.push(patterns[i]);
     }
     return noDup;
@@ -220,10 +220,10 @@ function checkResult() {
         for (var j= 0; j < friezeSize; j++) {
             items.solutionModel.setProperty(j, "shown_", true);
         }
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.goodAnswerSound.play();
         items.score.playWinAnimation();
     } else {
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.badAnswerSound.play();
         items.errorRectangle.startAnimation();
         items.buttonsBlocked = false;
     }
