@@ -264,14 +264,14 @@ function checkResult() {
     for (var i = 0; i < items.rowAnswer.count; i++) {
         var wordCard = items.rowAnswer.itemAt(i)
         if (wordCard.expected !== "")
-            ok = ok && (wordCard.expected === wordCard.proposition)
+            ok &= (wordCard.expected === wordCard.proposition)
     }
     if (ok){
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav")
+        items.goodAnswerSound.play()
         items.currentExercise += 1
         items.score.playWinAnimation()
     } else {
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
+        items.badAnswerSound.play()
         items.errorRectangle.startAnimation()
     }
 }
