@@ -11,10 +11,8 @@
 #include <QApplication>
 #include <QQuickWindow>
 #include <QQmlApplicationEngine>
-#include <QQmlComponent>
 #include <QStandardPaths>
 #include <QObject>
-#include <QTranslator>
 #include <QCommandLineParser>
 #include <QCursor>
 #include <QPixmap>
@@ -25,96 +23,6 @@
 #include "ActivityInfoTree.h"
 #include "DownloadManager.h"
 
-bool loadAndroidTranslation(QTranslator &translator, const QString &locale)
-{
-    QFile file("assets:/share/GCompris/gcompris_" + locale + ".qm");
-
-    file.open(QIODevice::ReadOnly);
-    QDataStream in(&file);
-    uchar *data = (uchar *)malloc(file.size());
-
-    if (!file.exists())
-        qDebug() << "file assets:/share/GCompris/gcompris_" << locale << ".qm does not exist";
-
-    in.readRawData((char *)data, file.size());
-
-    if (!translator.load(data, file.size())) {
-        qDebug() << "Unable to load translation for locale " << locale << ", use en_US by default";
-        free(data);
-        return false;
-    }
-    // Do not free data, it is still needed by translator
-    return true;
-}
-
-/**
- * Checks if the locale is supported. Locale may have been removed because
- * translation progress was not enough or invalid language put in configuration.
- */
-bool isSupportedLocale(const QString &locale)
-{
-    bool isSupported = false;
-    QQmlEngine engine;
-    QQmlComponent component(&engine, QUrl("qrc:/gcompris/src/core/LanguageList.qml"));
-    QObject *object = component.create();
-    if (!object) {
-        qWarning() << "isSupportedLocale:" << component.errors();
-        return false;
-    }
-    QVariant variant = object->property("languages");
-    QJSValue languagesList = variant.value<QJSValue>();
-    const int length = languagesList.property("length").toInt();
-    for (int i = 0; i < length; ++i) {
-        if (languagesList.property(i).property("locale").toString() == locale) {
-            isSupported = true;
-        }
-    }
-    delete object;
-    return isSupported;
-}
-// Return the locale
-QString loadTranslation(const QSettings &config, QTranslator &translator)
-{
-    QString locale = config.value("General/locale", GC_DEFAULT_LOCALE).toString();
-
-    if (!isSupportedLocale(locale)) {
-        qDebug() << "locale" << locale << "not supported, defaulting to" << GC_DEFAULT_LOCALE;
-        locale = GC_DEFAULT_LOCALE;
-        ApplicationSettings::getInstance()->setLocale(locale);
-    }
-
-    if (locale == GC_DEFAULT_LOCALE)
-        locale = QString(QLocale::system().name() + ".UTF-8");
-
-    if (locale == "C.UTF-8")
-        locale = "en_US.UTF-8";
-
-    // Load translation
-    // Remove .UTF8
-    locale.remove(".UTF-8");
-
-#if defined(Q_OS_ANDROID)
-    if (!loadAndroidTranslation(translator, locale))
-        loadAndroidTranslation(translator, ApplicationInfo::localeShort(locale));
-#else
-
-#if (defined(Q_OS_LINUX) || defined(Q_OS_UNIX))
-    // only useful for translators: load from $application_dir/../share/... if exists as it is where kde scripts install translations
-    if (translator.load("gcompris_qt.qm", QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale))) {
-        qDebug() << "load translation for locale " << locale << " in " << QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale);
-    }
-    else if (translator.load("gcompris_qt.qm", QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale.split('_')[0]))) {
-        qDebug() << "load translation for locale " << locale << " in " << QString("%1/../share/locale/%2/LC_MESSAGES").arg(QCoreApplication::applicationDirPath(), locale.split('_')[0]);
-    }
-    else
-#endif
-        if (!translator.load("gcompris_" + locale, QString("%1/%2/translations").arg(QCoreApplication::applicationDirPath(), GCOMPRIS_DATA_FOLDER))) {
-        qDebug() << "Unable to load translation for locale " << locale << ", use en_US by default";
-    }
-#endif
-    return locale;
-}
-
 int main(int argc, char *argv[])
 {
     // Disable it because we already support HDPI display natively
@@ -191,12 +99,16 @@ int main(int argc, char *argv[])
     parser.addOption(clWithKioskMode);
 
     QCommandLineOption clSoftwareRenderer(QStringList() << "software-renderer",
-                                          QObject::tr("Use software renderer instead of openGL (slower but should run with any graphical card)."));
+                                          QObject::tr("Use software renderer instead of openGL (slower but should run with any graphical card). Deprecated, use --renderer=software instead."));
     parser.addOption(clSoftwareRenderer);
     QCommandLineOption clOpenGLRenderer(QStringList() << "opengl-renderer",
-                                        QObject::tr("Use openGL renderer instead of software (faster but crash potentially depending on your graphical card)."));
+                                        QObject::tr("Use openGL renderer instead of software (faster but crash potentially depending on your graphical card). Deprecated, use --renderer=opengl instead."));
     parser.addOption(clOpenGLRenderer);
 
+    QCommandLineOption clRenderer(QStringList() << "renderer",
+                                        QObject::tr("Select renderer (opengl, software, Direct3D11, Direct3D12, Metal)."), "renderer");
+    parser.addOption(clRenderer);
+
     QCommandLineOption clStartOnActivity("launch",
                                          QObject::tr("Specify the activity when starting GCompris."), "activity");
     parser.addOption(clStartOnActivity);
@@ -220,12 +132,6 @@ int main(int argc, char *argv[])
     plugin.registerTypes("GCompris");
     ActivityInfoTree::registerResources();
 
-    // Load translations
-    QTranslator translator;
-    loadTranslation(config, translator);
-    // Apply translation
-    app.installTranslator(&translator);
-
     // Tell media players to stop playing, it's GCompris time
     ApplicationInfo::getInstance()->requestAudioFocus();
 
@@ -280,31 +186,39 @@ int main(int argc, char *argv[])
     if (parser.isSet(clWithKioskMode)) {
         ApplicationSettings::getInstance()->setKioskMode(true);
     }
+    // This will be removed later, for now, it is ignored if --renderer option is set
     if (parser.isSet(clSoftwareRenderer)) {
         ApplicationSettings::getInstance()->setRenderer(QStringLiteral("software"));
     }
     if (parser.isSet(clOpenGLRenderer)) {
         ApplicationSettings::getInstance()->setRenderer(QStringLiteral("opengl"));
     }
+    QMap<QString, QSGRendererInterface::GraphicsApi> existingRenderers;
+    existingRenderers[QLatin1String("software")] = QSGRendererInterface::Software;
+    existingRenderers[QLatin1String("opengl")] = QSGRendererInterface::OpenGL;
+#if defined(Q_OS_MACOS)
+    existingRenderers[QLatin1String("metal")] = QSGRendererInterface::Metal;
+#endif
+#if defined(Q_OS_WIN)
+    existingRenderers[QLatin1String("direct3d11")] = QSGRendererInterface::Direct3D11;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+    existingRenderers[QLatin1String("direct3d12")] = QSGRendererInterface::Direct3D12;
+#endif
+#endif
+    if(parser.isSet(clRenderer)) {
+        QString rendererValue = parser.value(clRenderer);
+        if(!existingRenderers.contains(rendererValue)) {
+            qWarning() << "Renderer" << rendererValue << "is not a supported renderer. Supported renderers:" << existingRenderers.keys();
+        }
+        else {
+            ApplicationSettings::getInstance()->setRenderer(rendererValue);
+        }
+    }
 
     // Set the renderer used
     const QString &renderer = ApplicationSettings::getInstance()->renderer();
-    ApplicationInfo::getInstance()->setUseOpenGL(renderer != QLatin1String("software"));
-
-    if (renderer == QLatin1String("software")) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-        QQuickWindow::setGraphicsApi(QSGRendererInterface::Software);
-#else
-        QQuickWindow::setSceneGraphBackend(QSGRendererInterface::Software);
-#endif
-    }
-    else if (renderer == QLatin1String("opengl")) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-        QQuickWindow::setGraphicsApi(QSGRendererInterface::OpenGL);
-#else
-        QQuickWindow::setSceneGraphBackend(QSGRendererInterface::OpenGL);
-#endif
-    }
+    ApplicationInfo::getInstance()->setUseSoftwareRenderer(renderer == QLatin1String("software"));
+    QQuickWindow::setGraphicsApi(existingRenderers[renderer]);
 
     // Start on specific activity
     if (parser.isSet(clStartOnActivity)) {
@@ -318,9 +232,13 @@ int main(int argc, char *argv[])
             }
         }
         // internally, levels start at 0
-        ActivityInfoTree::setStartingActivity(startingActivity, startingLevel - 1);
+        ActivityInfoTree::getInstance()->setStartingActivity(startingActivity, startingLevel - 1);
     }
 
+    // Load translations
+    QString locale = config.value("General/locale", GC_DEFAULT_LOCALE).toString();
+    ApplicationInfo::getInstance()->switchLocale(locale);
+
     QQmlApplicationEngine engine;
     QObject::connect(&engine, &QQmlApplicationEngine::quit, DownloadManager::getInstance(),
                      &DownloadManager::shutdown);
@@ -328,14 +246,36 @@ int main(int argc, char *argv[])
     engine.addImportPath(QStringLiteral("%1/../lib/qml")
                              .arg(QCoreApplication::applicationDirPath()));
 
-#if __ANDROID__ && QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+#if __ANDROID__
     // Find box2d
     engine.addImportPath(QStringLiteral("assets:/"));
 #endif
 
     ApplicationInfo::getInstance()->setBox2DInstalled(engine);
+
     // We load the main file after checking for box2d to avoid computing multiple times the menu
     engine.load(QUrl("qrc:/gcompris/src/core/main.qml"));
+    QObject *topLevel = engine.rootObjects().value(0);
+
+    QQuickWindow *window = qobject_cast<QQuickWindow *>(topLevel);
+    if (window == nullptr) {
+        qWarning("Error: Your root item has to be a Window.");
+        return -1;
+    }
+    ApplicationInfo::setWindow(window);
+
+    window->setIcon(QIcon(QPixmap(QString::fromUtf8(":/gcompris/src/core/resource/gcompris-icon.png"))));
+
+#if !__ANDROID__
+    if (isFullscreen) {
+        window->showFullScreen();
+    }
+    else {
+        window->show();
+    }
+#endif
+
+    ActivityInfoTree::getInstance()->initialize(&engine);
 
     if (parser.isSet(exportActivitiesAsSQL)) {
         ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree *>(ActivityInfoTree::menuTreeProvider(&engine, nullptr)));
@@ -374,30 +314,18 @@ int main(int argc, char *argv[])
         qDebug() << QStringLiteral("Setting difficulty between %1 and %2").arg(minDifficulty).arg(maxDifficulty);
         ApplicationSettings::getInstance()->setDifficultyFromCommandLine(minDifficulty, maxDifficulty);
         ActivityInfoTree::getInstance()->minMaxFiltersChanged(minDifficulty, maxDifficulty, false);
-        ActivityInfoTree::getInstance()->filterByTag("favorite");
-        if(parser.isSet(clStartOnActivity) && ActivityInfoTree::getInstance()->launchedActivityMissGivenDifficulty()){
+        ActivityInfoTree::getInstance()->filterByTag("favorite", "", false);
+        if (parser.isSet(clStartOnActivity) && ActivityInfoTree::getInstance()->launchedActivityMissGivenDifficulty()) {
             qWarning() << "The launched activity doesn't contain any level for given difficulty range";
             return -1;
         }
     }
 
-    QObject *topLevel = engine.rootObjects().value(0);
+    topLevel->setProperty("activitiesLoaded", true);
 
-    QQuickWindow *window = qobject_cast<QQuickWindow *>(topLevel);
-    if (window == nullptr) {
-        qWarning("Error: Your root item has to be a Window.");
-        return -1;
-    }
-    ApplicationInfo::setWindow(window);
-
-    window->setIcon(QIcon(QPixmap(QString::fromUtf8(":/gcompris/src/core/resource/gcompris-icon.png"))));
-
-    if (isFullscreen) {
-        window->showFullScreen();
-    }
-    else {
-        window->show();
-    }
+#if __ANDROID__
+    window->showMaximized();
+#endif
 
     return app.exec();
 }
